@@ -10,7 +10,7 @@ class PDF::Font::Loader::FreeType {
     use PDF::Font::Loader::Enc::Identity;
     use PDF::Font::Loader::Enc::Identity-H;
     use PDF::Font::Loader::Enc::Type1;
-    use Font::FreeType:ver(v0.0.9+);
+    use Font::FreeType:ver(v0.1.9+);
     use Font::FreeType::Face;
     use Font::FreeType::Error;
     use Font::FreeType::Native;
@@ -298,7 +298,7 @@ class PDF::Font::Loader::FreeType {
         my FT_Pos $y = 0;
         my FT_UInt $prev-idx = 0;
         my FT_Vector $kerning .= new;
-        my $struct = $!face.struct;
+        my $struct = $!face.native;
         my $glyph-slot = $struct.glyph;
         my Numeric $stringwidth = 0;
         my $scale = 1000 / ($!face.units-per-EM || 1000);
@@ -325,7 +325,7 @@ class PDF::Font::Loader::FreeType {
     }
 
     method !char-height(UInt $char-code) {
-        my $face-struct = $!face.struct;
+        my $face-struct = $!face.native;
         my $glyph-slot = $face-struct.glyph;
         my $scale = 1000 / ($!face.units-per-EM || 1000);
         my FT_UInt $idx = $face-struct.FT_Get_Char_Index( $char-code );
@@ -342,7 +342,7 @@ class PDF::Font::Loader::FreeType {
         my FT_UInt      $prev-idx = 0;
         my Bool         $has-kerning = $!face.has-kerning;
         my FT_Vector    $kerning .= new;
-        my FT_Face      $face-struct = $!face.struct;
+        my FT_Face      $face-struct = $!face.native;
         my FT_GlyphSlot $glyph-slot = $face-struct.glyph;
         my Str          $str = '';
         my Numeric      $stringwidth = 0.0;
